@@ -7,6 +7,9 @@ from datetime import datetime, timedelta
 from collections import defaultdict
 
 from . import database, version, archiver_listeners
+from .configs import Config
+
+config = Config()
 
 SUPPORTED_TIMESTAMP_FORMATS = (
         "%Y%m%d %H:%M:%S.%f",
@@ -23,8 +26,6 @@ SUPPORTED_TIMESTAMP_FORMATS = (
         "%Y-%m-%dT%H:%M:%S.%f%z",
     )
 
-MAX_LOG_MESSAGE_LENGTH = 2000
-
 
 class TimeAdjust:
     def __init__(self, secs, adjust_to_system):
@@ -463,9 +464,18 @@ class LogMessage(TestItem):
     def insert(self, content):
         if (not self.archiver.config.ignore_logs and
                 not self.archiver.config.log_level_ignored(self.log_level)):
+            message_length = config.max_log_message_length
+
+            if message_length < 0:
+                message = content[message_length:]
+            elif message_length > 0:
+                message = content[:message_length]
+            else:
+                message = content
             data = {'test_run_id': self.test_run_id(),
                     'timestamp': adjusted_timestamp(self.timestamp, self.archiver.time_adjust.secs()),
-                    'log_level': self.log_level, 'message': content[:MAX_LOG_MESSAGE_LENGTH],
+                    'log_level': self.log_level,
+                    'message': message,
                     'test_id': self.parent_test().id if self.parent_test() else None,
                     'suite_id': self.parent_suite().id,
                     'execution_path': self.execution_path()}
@@ -475,20 +485,20 @@ class LogMessage(TestItem):
         return self.parent_item.execution_path()
 
 
-def database_connection(config):
-    return database.get_connection_and_check_schema(config)
+def database_connection(configuration):
+    return database.get_connection_and_check_schema(configuration)
 
 
 class Archiver:
-    def __init__(self, connection, config, build_number_cache=None):
-        self.config = config
+    def __init__(self, connection, configuration, build_number_cache=None):
+        self.config = configuration
         self.test_type = None
-        self.additional_metadata = config.metadata
+        self.additional_metadata = self.config.metadata
         self.test_run_id = None
         self.test_series = {}
-        self.team = config.team
-        self.series = config.series
-        self.repository = config.repository
+        self.team = self.config.team
+        self.series = self.config.series
+        self.repository = self.config.repository
 
         self.archived_using = None
         self.output_from_dryrun = False
@@ -496,16 +506,17 @@ class Archiver:
         self.stack = []
         self.keyword_statistics = {}
         self.build_number_cache = build_number_cache or {}
-        self.execution_context = config.execution_context
-        self.changes = config.changes
-        self.execution_id = config.execution_id
+        self.execution_context = self.config.execution_context
+        self.changes = self.config.changes
+        self.execution_id = self.config.execution_id
 
-        self.time_adjust = TimeAdjust(config.time_adjust_secs,
-                                      config.time_adjust_with_system_timezone)
+        self.time_adjust = TimeAdjust(self.config.time_adjust_secs,
+                                      self.config.time_adjust_with_system_timezone)
 
         self.listeners = []
-        if config.change_engine_url:
-            self.listeners.append(archiver_listeners.ChangeEngineListener(self, config.change_engine_url))
+        if self.config.change_engine_url:
+            self.listeners.append(
+                archiver_listeners.ChangeEngineListener(self, self.config.change_engine_url))
 
     def current_item(self, expected_type=None):
         item = self.stack[-1] if self.stack else None
